==> dxcr-vue-cesium-0.0.1.tgz: package/lib/datasource/custom/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import mixinDatasource from '../../mixins/datasource/mixinDatasource';

var script = {
  name: 'vc-datasource-custom',
  mixins: [mixinDatasource],
  props: {
    name: String,
    entities: {
      type: Array,
      default: function _default() {
        return [];
      }
    }
  },
  methods: {
    /**
     *  重写 createCesiumObject 方法，支持用数组加载大量 entities
     */
    createCesiumObject: function createCesiumObject() {
      var name, transformProps, entities, ds;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              name = this.name, transformProps = this.transformProps, entities = this.entities;
              ds = new Cesium.CustomDataSource(name);
              entities.forEach(function (entity) {
                var entityOptions = transformProps(entity);
                ds.entities.add(entityOptions);
              });
              return _context.abrupt("return", ds);

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "CustomDataSource.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var CustomDataSource = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(CustomDataSource.name, CustomDataSource);
}

export default plugin;
export { CustomDataSource, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/datasource/custom/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import mixinDatasource from '../../mixins/datasource/mixinDatasource';

var script = {
  name: 'vc-datasource-custom',
  mixins: [mixinDatasource],
  props: {
    name: String
  },
  methods: {
    /**
     *  重写 createCesiumObject 方法
     */
    createCesiumObject: function createCesiumObject() {
      var name, ds;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              name = this.name;
              ds = new Cesium.CustomDataSource(name);
              return _context.abrupt("return", ds);

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "CustomDataSource.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var CustomDataSource = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(CustomDataSource.name, CustomDataSource);
}

export default plugin;
export { CustomDataSource, plugin as install };
